@@ -1,10 +1,11 @@
 ################################################################################
 # 
 # StartingParams.R
-# Version 1.1
-# 30/01/2015
+# Version 1.2
+# 18/08/2016
 #
 # Updates:
+#   18/08/2016: names of starting parameters harmonised with paper
 #   30/01/2015: Thomas model added
 #
 # Dataframes containing the starting parameters for the optimisation procedure
@@ -31,19 +32,19 @@ ParamsPL <- data.frame("C" = 0.01, "z" = 0.01)
 ParamsLogis <- data.frame("C" = 0.01, "z" = 0.01)
 
 ### Poisson model
-ParamsPoisson <- data.frame("lambda" = 1e-8)
+ParamsPoisson <- data.frame("gamma" = 1e-8)
 
 ### Negative binomial model
-ParamsNB <- data.frame("C" = 0.01, "k" = 0.01)
+ParamsNB <- data.frame("gamma" = 0.01, "k" = 0.01)
 
 ### Generalised negative binomial model
 ParamsGNB <- data.frame("C" = 0.00001, "z" = 1, "k" = 0.01)
 
 ### Improved negative binomial model
-ParamsINB <- data.frame("C" = 1, "r" = 0.01, "b" = 0.1)
+ParamsINB <- data.frame("C" = 1, "gamma" = 0.01, "b" = 0.1)
 
 ### Finite negative binomial model
-ParamsFNB <- data.frame("W" = 10, "k" = 10)
+ParamsFNB <- data.frame("N" = 10, "k" = 10)
 
 ### Thomas model
 ParamsThomas <- data.frame("rho" = 1e-8, "mu" = 10,"sigma" = 1)
